@@ -448,8 +448,13 @@ class Aka(callbacks.Plugin):
             if biggestDollar or biggestAt:
                 args = getArgs(args, required=biggestDollar, optional=biggestAt,
                                 wildcard=wildcard)
-            max_len = conf.supybot.reply.maximumLength()
-            args = list([x[:max_len] for x in args])
+            remaining_len = conf.supybot.reply.maximumLength()
+            for (i, arg) in enumerate(args):
+                if remaining_len < len(arg):
+                    arg = arg[0:remaining_len]
+                    args[i+1:] = []
+                    break
+                remaining_len -= len(arg)
             def regexpReplace(m):
                 idx = int(m.group(1))
                 return args[idx-1]
@@ -462,33 +467,32 @@ class Aka(callbacks.Plugin):
             replace(tokens, lambda s: dollarRe.sub(regexpReplace, s))
             if biggestAt:
                 assert not wildcard
-                args = args[biggestDollar:]
                 replace(tokens, lambda s: atRe.sub(regexpReplace, s))
             if wildcard:
                 assert not biggestAt
                 # Gotta remove the things that have already been subbed in.
                 i = biggestDollar
-                while i:
-                    args.pop(0)
-                    i -= 1
+                args[:] = args[i:]
                 def everythingReplace(tokens):
+                    skip = 0
                     for (i, token) in enumerate(tokens):
+                        if skip:
+                            skip -= 1
+                            continue
                         if isinstance(token, list):
-                            if everythingReplace(token):
-                                return
+                            everythingReplace(token)
                         if token == '$*':
                             tokens[i:i+1] = args
-                            return True
+                            skip = len(args)-1 # do not make replacements in
+                                               # tokens we just added
                         elif '$*' in token:
                             tokens[i] = token.replace('$*', ' '.join(args))
-                            return True
-                    return False
                 everythingReplace(tokens)
             maxNesting = conf.supybot.commands.nested.maximum()
             if maxNesting and irc.nested+1 > maxNesting:
                 irc.error(_('You\'ve attempted more nesting than is '
                       'currently allowed on this bot.'), Raise=True)
-            self.Proxy(irc, msg, tokens)
+            self.Proxy(irc, msg, tokens, nested=irc.nested+1)
         if biggestDollar and (wildcard or biggestAt):
             flexargs = _(' at least')
         else:
@@ -520,8 +524,6 @@ class Aka(callbacks.Plugin):
         wildcard = '$*' in alias
         if biggestAt and wildcard:
             raise AkaError(_('Can\'t mix $* and optional args (@1, etc.)'))
-        if alias.count('$*') > 1:
-            raise AkaError(_('There can be only one $* in an alias.'))
         self._db.add_aka(channel, name, alias)
 
     def _remove_aka(self, channel, name, evenIfLocked=False):
